/*
 * Copyright (c) 2005-2010 KOM – Multimedia Communications Lab
 *
 * This file is part of Simonstrator.KOM.
 * 
 * Simonstrator.KOM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * PeerfactSim.KOM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with PeerfactSim.KOM.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


package de.tudarmstadt.maki.simonstrator.api.component.sensor.environment.data;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * @author Tobias Meuser (tobias.meuser@kom.tu-darmstadt.de)
 * @version 1.0 at 27.02.2018
 *
 */
public class Environment {
	private List<EnvironmentProperty> _properties;

	public Environment() {
		this(new ArrayList<>());
	}

	public Environment(List<EnvironmentProperty> pProperties) {
		_properties = pProperties;
	}

	public void addProperty(EnvironmentProperty pProperty) {
		_properties.add(pProperty);
	}

	public List<EnvironmentProperty> getProperties() {
		return Collections.unmodifiableList(_properties);
	}

	public <T extends Object> List<T> getProperties(Class<T> pClass) {
		List<T> results = new ArrayList<>();

		for (EnvironmentProperty environmentProperty : _properties) {
			if (pClass.isAssignableFrom(environmentProperty.getClass())) {
				results.add((T) environmentProperty);
			}
		}

		return results;
	}
}
